Credits
=======

Development Lead
----------------

* George Pchelkin @gpchelkin <george@pchelk.in>

Contributors
------------

* Leonid Runyshkin @leovp
* Vadim Larionov @vadimlarionov <larionov.vadim@mail.ru>
